package somcolorapp;

/**
 * Package somcolorapp
 * Classification des couleurs avec un rseau de Kohonen.
 * Rseaux Neauronaux, Vuibert 2006.
 * Jean-Philippe Rennard
 * version 1.0, 17/3/2006
 */

import java.awt.*;
import baseui.*;

/**
 * <p>Title: Vue de l'applet Nim</p>
 * <p>Description: Interface graphique de l'applet.</p>
 */
public class SOMColorVue extends Cvue {
  /** Pointeur sur processus */
  SOMColorProcess processSOM;
  /** Dimension horizontale d'une cellule */
  float dimCellHoriz;
  /** Dimension verticale d'une cellule */
  float dimCellVertic;
  /** Largeur cellule */
  private int largeurCell;
  /** Hauteur cellule */
  private int hauteurCell;

  /** Constructeur dans un processus */
  public SOMColorVue(SOMColorProcess p) {
    super(Color.black, Color.white, Cvue.REPRANISOTROPIC);
    processSOM = p;
  }

  /** Constructeur dans un processus avec couleurs */
  public SOMColorVue(SOMColorProcess p, Color c, Color f) {
    super(c, f, Cvue.REPRISOTROPIC);
    processSOM = p;
  }

  /** Affichage de la carte */
  public void afficheCarte() {
    afficheFond();
    afficheGrille();
  }

  /** Affichage du fond */
  public void afficheFond() {
    effaceFond();
  }

  /** Fixe la taille des cellules */
  public void setTailleCell() {
    dimCellHoriz = lLargeur/processSOM.tailleCarte;
    dimCellVertic = lHauteur/processSOM.tailleCarte;
    largeurCell = Math.max(lLongueurToRX(dimCellHoriz), 1);
    hauteurCell = Math.max(lLongueurToRY(dimCellVertic), 1);
  }

  /**
   * Affiche une cellule
   * @param x int : position en x
   * @param y int : position en y
   * @param c Color : couleur de la cellule
   */
  public void afficheCellule(int x, int y, Color c) {
    grBuff.setColor(c);
    grBuff.fillRect(lToRX(x*dimCellHoriz),
                          lToRY(y*dimCellVertic), largeurCell+1, hauteurCell+1);
  }

  /** Affiche l'ensemble des cellules */
  public void afficheGrille() {
    for(int x=0; x<processSOM.tailleCarte; x++)
      for(int y=0; y<processSOM.tailleCarte; y++)
        afficheCellule(x, y, processSOM.leReseau.getCouleurNeurone(x, y));
  }

  /** Changement de taille de la vue */
  public void setNewSize() {
    redimGrBuff();
    setTailleCell();
    afficheFond();
    afficheGrille();
    repaint();
  }
}
